@@ -15,7 +15,6 @@ import sys
 from typing import IO, Any, Dict, List, Type, Union
 
 from botocore.client import ClientMeta
-from botocore.exceptions import ClientError as Boto3ClientError
 
 from mypy_boto3_secretsmanager.paginator import ListSecretsPaginator
 from mypy_boto3_secretsmanager.type_defs import (
@@ -50,25 +49,33 @@ else:
 __all__ = ("SecretsManagerClient",)
 
 
+class BotocoreClientError(BaseException):
+    MSG_TEMPLATE: str
+
+    def __init__(self, error_response: Dict[str, Any], operation_name: str) -> None:
+        self.response: Dict[str, Any]
+        self.operation_name: str
+
+
 class Exceptions:
-    ClientError: Type[Boto3ClientError]
-    DecryptionFailure: Type[Boto3ClientError]
-    EncryptionFailure: Type[Boto3ClientError]
-    InternalServiceError: Type[Boto3ClientError]
-    InvalidNextTokenException: Type[Boto3ClientError]
-    InvalidParameterException: Type[Boto3ClientError]
-    InvalidRequestException: Type[Boto3ClientError]
-    LimitExceededException: Type[Boto3ClientError]
-    MalformedPolicyDocumentException: Type[Boto3ClientError]
-    PreconditionNotMetException: Type[Boto3ClientError]
-    PublicPolicyException: Type[Boto3ClientError]
-    ResourceExistsException: Type[Boto3ClientError]
-    ResourceNotFoundException: Type[Boto3ClientError]
+    ClientError: Type[BotocoreClientError]
+    DecryptionFailure: Type[BotocoreClientError]
+    EncryptionFailure: Type[BotocoreClientError]
+    InternalServiceError: Type[BotocoreClientError]
+    InvalidNextTokenException: Type[BotocoreClientError]
+    InvalidParameterException: Type[BotocoreClientError]
+    InvalidRequestException: Type[BotocoreClientError]
+    LimitExceededException: Type[BotocoreClientError]
+    MalformedPolicyDocumentException: Type[BotocoreClientError]
+    PreconditionNotMetException: Type[BotocoreClientError]
+    PublicPolicyException: Type[BotocoreClientError]
+    ResourceExistsException: Type[BotocoreClientError]
+    ResourceNotFoundException: Type[BotocoreClientError]
 
 
 class SecretsManagerClient:
     """
-    [SecretsManager.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.53/reference/services/secretsmanager.html#SecretsManager.Client)
+    [SecretsManager.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.58/reference/services/secretsmanager.html#SecretsManager.Client)
     """
 
     meta: ClientMeta
@@ -76,12 +83,12 @@ class SecretsManagerClient:
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.53/reference/services/secretsmanager.html#SecretsManager.Client.can_paginate)
+        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.58/reference/services/secretsmanager.html#SecretsManager.Client.can_paginate)
         """
 
     def cancel_rotate_secret(self, SecretId: str) -> CancelRotateSecretResponseTypeDef:
         """
-        [Client.cancel_rotate_secret documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.53/reference/services/secretsmanager.html#SecretsManager.Client.cancel_rotate_secret)
+        [Client.cancel_rotate_secret documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.58/reference/services/secretsmanager.html#SecretsManager.Client.cancel_rotate_secret)
         """
 
     def create_secret(
@@ -95,12 +102,12 @@ class SecretsManagerClient:
         Tags: List["TagTypeDef"] = None,
     ) -> CreateSecretResponseTypeDef:
         """
-        [Client.create_secret documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.53/reference/services/secretsmanager.html#SecretsManager.Client.create_secret)
+        [Client.create_secret documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.58/reference/services/secretsmanager.html#SecretsManager.Client.create_secret)
         """
 
     def delete_resource_policy(self, SecretId: str) -> DeleteResourcePolicyResponseTypeDef:
         """
-        [Client.delete_resource_policy documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.53/reference/services/secretsmanager.html#SecretsManager.Client.delete_resource_policy)
+        [Client.delete_resource_policy documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.58/reference/services/secretsmanager.html#SecretsManager.Client.delete_resource_policy)
         """
 
     def delete_secret(
@@ -110,12 +117,12 @@ class SecretsManagerClient:
         ForceDeleteWithoutRecovery: bool = None,
     ) -> DeleteSecretResponseTypeDef:
         """
-        [Client.delete_secret documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.53/reference/services/secretsmanager.html#SecretsManager.Client.delete_secret)
+        [Client.delete_secret documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.58/reference/services/secretsmanager.html#SecretsManager.Client.delete_secret)
         """
 
     def describe_secret(self, SecretId: str) -> DescribeSecretResponseTypeDef:
         """
-        [Client.describe_secret documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.53/reference/services/secretsmanager.html#SecretsManager.Client.describe_secret)
+        [Client.describe_secret documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.58/reference/services/secretsmanager.html#SecretsManager.Client.describe_secret)
         """
 
     def generate_presigned_url(
@@ -126,7 +133,7 @@ class SecretsManagerClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.53/reference/services/secretsmanager.html#SecretsManager.Client.generate_presigned_url)
+        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.58/reference/services/secretsmanager.html#SecretsManager.Client.generate_presigned_url)
         """
 
     def get_random_password(
@@ -141,19 +148,19 @@ class SecretsManagerClient:
         RequireEachIncludedType: bool = None,
     ) -> GetRandomPasswordResponseTypeDef:
         """
-        [Client.get_random_password documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.53/reference/services/secretsmanager.html#SecretsManager.Client.get_random_password)
+        [Client.get_random_password documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.58/reference/services/secretsmanager.html#SecretsManager.Client.get_random_password)
         """
 
     def get_resource_policy(self, SecretId: str) -> GetResourcePolicyResponseTypeDef:
         """
-        [Client.get_resource_policy documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.53/reference/services/secretsmanager.html#SecretsManager.Client.get_resource_policy)
+        [Client.get_resource_policy documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.58/reference/services/secretsmanager.html#SecretsManager.Client.get_resource_policy)
         """
 
     def get_secret_value(
         self, SecretId: str, VersionId: str = None, VersionStage: str = None
     ) -> GetSecretValueResponseTypeDef:
         """
-        [Client.get_secret_value documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.53/reference/services/secretsmanager.html#SecretsManager.Client.get_secret_value)
+        [Client.get_secret_value documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.58/reference/services/secretsmanager.html#SecretsManager.Client.get_secret_value)
         """
 
     def list_secret_version_ids(
@@ -164,7 +171,7 @@ class SecretsManagerClient:
         IncludeDeprecated: bool = None,
     ) -> ListSecretVersionIdsResponseTypeDef:
         """
-        [Client.list_secret_version_ids documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.53/reference/services/secretsmanager.html#SecretsManager.Client.list_secret_version_ids)
+        [Client.list_secret_version_ids documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.58/reference/services/secretsmanager.html#SecretsManager.Client.list_secret_version_ids)
         """
 
     def list_secrets(
@@ -175,14 +182,14 @@ class SecretsManagerClient:
         SortOrder: Literal["asc", "desc"] = None,
     ) -> ListSecretsResponseTypeDef:
         """
-        [Client.list_secrets documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.53/reference/services/secretsmanager.html#SecretsManager.Client.list_secrets)
+        [Client.list_secrets documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.58/reference/services/secretsmanager.html#SecretsManager.Client.list_secrets)
         """
 
     def put_resource_policy(
         self, SecretId: str, ResourcePolicy: str, BlockPublicPolicy: bool = None
     ) -> PutResourcePolicyResponseTypeDef:
         """
-        [Client.put_resource_policy documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.53/reference/services/secretsmanager.html#SecretsManager.Client.put_resource_policy)
+        [Client.put_resource_policy documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.58/reference/services/secretsmanager.html#SecretsManager.Client.put_resource_policy)
         """
 
     def put_secret_value(
@@ -194,12 +201,12 @@ class SecretsManagerClient:
         VersionStages: List[str] = None,
     ) -> PutSecretValueResponseTypeDef:
         """
-        [Client.put_secret_value documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.53/reference/services/secretsmanager.html#SecretsManager.Client.put_secret_value)
+        [Client.put_secret_value documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.58/reference/services/secretsmanager.html#SecretsManager.Client.put_secret_value)
         """
 
     def restore_secret(self, SecretId: str) -> RestoreSecretResponseTypeDef:
         """
-        [Client.restore_secret documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.53/reference/services/secretsmanager.html#SecretsManager.Client.restore_secret)
+        [Client.restore_secret documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.58/reference/services/secretsmanager.html#SecretsManager.Client.restore_secret)
         """
 
     def rotate_secret(
@@ -210,17 +217,17 @@ class SecretsManagerClient:
         RotationRules: "RotationRulesTypeTypeDef" = None,
     ) -> RotateSecretResponseTypeDef:
         """
-        [Client.rotate_secret documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.53/reference/services/secretsmanager.html#SecretsManager.Client.rotate_secret)
+        [Client.rotate_secret documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.58/reference/services/secretsmanager.html#SecretsManager.Client.rotate_secret)
         """
 
     def tag_resource(self, SecretId: str, Tags: List["TagTypeDef"]) -> None:
         """
-        [Client.tag_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.53/reference/services/secretsmanager.html#SecretsManager.Client.tag_resource)
+        [Client.tag_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.58/reference/services/secretsmanager.html#SecretsManager.Client.tag_resource)
         """
 
     def untag_resource(self, SecretId: str, TagKeys: List[str]) -> None:
         """
-        [Client.untag_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.53/reference/services/secretsmanager.html#SecretsManager.Client.untag_resource)
+        [Client.untag_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.58/reference/services/secretsmanager.html#SecretsManager.Client.untag_resource)
         """
 
     def update_secret(
@@ -233,7 +240,7 @@ class SecretsManagerClient:
         SecretString: str = None,
     ) -> UpdateSecretResponseTypeDef:
         """
-        [Client.update_secret documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.53/reference/services/secretsmanager.html#SecretsManager.Client.update_secret)
+        [Client.update_secret documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.58/reference/services/secretsmanager.html#SecretsManager.Client.update_secret)
         """
 
     def update_secret_version_stage(
@@ -244,17 +251,17 @@ class SecretsManagerClient:
         MoveToVersionId: str = None,
     ) -> UpdateSecretVersionStageResponseTypeDef:
         """
-        [Client.update_secret_version_stage documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.53/reference/services/secretsmanager.html#SecretsManager.Client.update_secret_version_stage)
+        [Client.update_secret_version_stage documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.58/reference/services/secretsmanager.html#SecretsManager.Client.update_secret_version_stage)
         """
 
     def validate_resource_policy(
         self, ResourcePolicy: str, SecretId: str = None
     ) -> ValidateResourcePolicyResponseTypeDef:
         """
-        [Client.validate_resource_policy documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.53/reference/services/secretsmanager.html#SecretsManager.Client.validate_resource_policy)
+        [Client.validate_resource_policy documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.58/reference/services/secretsmanager.html#SecretsManager.Client.validate_resource_policy)
         """
 
     def get_paginator(self, operation_name: Literal["list_secrets"]) -> ListSecretsPaginator:
         """
-        [Paginator.ListSecrets documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.53/reference/services/secretsmanager.html#SecretsManager.Paginator.ListSecrets)
+        [Paginator.ListSecrets documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.58/reference/services/secretsmanager.html#SecretsManager.Paginator.ListSecrets)
         """
